import React from "react"
import { FetchPost, MediaPathTrc, SinglePost_t } from "./api"
import { z } from 'zod/v4'
import { useInfiniteQuery } from "@tanstack/react-query"

// type fetched = z.infer<typeof FetchPost_t>

const Single = ({ post }: { post: z.infer<typeof SinglePost_t> }) => {
	return (
		<div className="w-full max-w-2xl bg-gray-200 rounded-lg shadow-md p-6 flex flex-col gap-4 snap-start">
			<p className="text-gray-800 text-base leading-relaxed">{post.content}</p>
			{post.enclosure.length > 0 && post.enclosure[0] != null && <div className="flex flex-row overflow-x-auto gap-3 py-2 -mx-2 px-2 border-t border-gray-200 pt-4">
				{post.enclosure.map((enc, index) => {
					if (enc) {
						return <img
							key={index}
							src={MediaPathTrc(enc)}
							alt={`Post media ${post.id}-${index}`}
							className="rounded-md h-32 object-cover aspect-video flex-shrink-0"
						/>
					} else {
						return ""
					}
				})}
			</div>}
			{post.signing && <p className="text-right text-sm text-gray-600 italic mt-2">by: {post.signing}</p>}
			<div className="flex justify-between items-center text-xs text-gray-500 border-t border-gray-100 pt-3">
				<p className="self-start">PID: {post.id}</p>
				<p className="self-end">發文於: {post.post_at.toLocaleTimeString()}</p>
			</div>
		</div>
	)
}

export const Fetch = () => {
	const {
		data,
		error,
		fetchNextPage,
		hasNextPage,
		isFetching,
		status,
	} = useInfiniteQuery({
		queryKey: ['id'],
		queryFn: async ({ pageParam }) => {
			return await FetchPost(pageParam == 0 ? undefined : pageParam)
		},
		initialPageParam: 0,
		getNextPageParam: (lastPage, _) => {
			return lastPage !== null && lastPage.length > 0 && (lastPage[lastPage.length - 1].id - 1) > 0 ? lastPage[lastPage.length - 1].id - 1 : undefined
		},
	})
	return (
		<div className="h-dvh w-dvw flex flex-col items-center gap-6 py-8 px-4 overflow-scroll snap-y" onScroll={(ev) => {
			if (ev.currentTarget.scrollTop / (ev.currentTarget.scrollHeight - ev.currentTarget.clientHeight) >= 0.95) {
				if (hasNextPage && !isFetching) {
					fetchNextPage()
				}

			}
		}}>
			{status === 'pending' && <p>Loading</p>}
			{status === 'error' && <p>Error: {error.message}</p>}
			{data && data.pages.map((group, i) => (
				<React.Fragment key={i}>
					{group && group.map(post => (
						<Single post={post} key={post.id} />
					))}
				</React.Fragment>
			))}
			<div className={"w-full max-w-2xl bg-gray-200 rounded-lg shadow-md p-6 flex flex-col gap-4 animate-pulse mb-10" + (hasNextPage ? "" : " hidden")} id="skeleton">
			</div>
			{!hasNextPage && <p className="mb-15">見底了</p>}
		</div>
	)
}
